@@ -2,4 +2,4 @@ from ._token import GenerateToken
 from ._token import generateBearerToken
 from ._token import ResponseToken
 from ._token import generateBearerTokenFromCreds
-from ._validity import isValid
\ No newline at end of file
+from ._validity import isExpired, isValid
